@@ -383,6 +383,8 @@ class WebSocket(object):
         timeout: timeout time(second).
         """
         self._timeout = timeout
+        if self.sock:
+            self.sock.settimeout(timeout)
 
     timeout = property(gettimeout, settimeout)
 
@@ -419,6 +421,7 @@ class WebSocket(object):
         if not addrinfo_list:
             raise WebSocketException("Host not found.: " + hostname + ":" + str(port))
 
+        err = None
         for addrinfo in addrinfo_list:
             family = addrinfo[0]
             self.sock = socket.socket(family)
@@ -432,14 +435,16 @@ class WebSocket(object):
             try:
                 self.sock.connect(address)
             except socket.error as error:
+                error.remote_ip = str(address[0])
                 if error.errno in (errno.ECONNREFUSED, ):
+                    err = error
                     continue
                 else:
                     raise
             else:
                 break
         else:
-            raise error
+            raise err
 
         if proxy_host:
             self._tunnel(hostname, port)
